@@ -608,7 +608,7 @@ CONFIGLOOP: {
 		$var = $1;
 		$value = $2;
 		($lvar = $var) =~ tr/A-Z/a-z/;
-		my($codere) = '[\w-_#/.:]+';
+		my($codere) = '[-\w_#/.:]+';
 
 		if ($value =~ /^(.*)<<(\w+)\s*/) {                  # "here" value
 			my $begin  = $1 || '';
@@ -917,7 +917,7 @@ sub global_config {
 		$var = $1;
 		$value = $2;
 		($lvar = $var) =~ tr/A-Z/a-z/;
-		my($codere) = '[\w-_#/.]+';
+		my($codere) = '[-\w_#/.]+';
 
 		if ($value =~ /^(.*)<<(\w+)\s*/) {                  # "here" value
 			my $begin  = $1 || '';
