@@ -614,7 +614,7 @@ sub pgp_encrypt {
 
 sub check_order {
 	my ($profile) = @_;
-    my($codere) = '[\w-_#/.]+';
+    my($codere) = '[-\w_#/.]+';
 	my $params;
 	if(defined $Vend::Cfg->{'OrderProfileName'}->{$profile}) {
 		$profile = $Vend::Cfg->{'OrderProfileName'}->{$profile};
