@@ -932,7 +932,7 @@ sub perform_search {
 		}
 
 		@specs = ($options{'search_spec'}) 
-			unless defined @specs;
+			unless @specs;
 
 		if(defined $options{mv_return_spec}) {
 			$q->global('matches', 1) 
