@@ -356,6 +356,10 @@ sub http_server {
 
 	my (@path) = $url->path_components();
 	my $path = $url->path();
+	my $origpath = $path;
+	if($path =~ s{\.\./}{}g) {
+		::logGlobal("Attempted breakin (asked for $origpath), will 404 the file.");
+	}
 	my $doc;
 	my $status = 200;
 
@@ -398,7 +402,7 @@ EOF
 #::logGlobal("not found");
 		$status = 404;
 		$Vend::StatusLine = "HTTP/1.0 404 Not found";
-		$doc = "$path not a MiniVend catalog or help file.\n";
+		$doc = "$origpath not a MiniVend catalog or help file.\n";
 	}
 
 	if($$env{REQUEST_METHOD} eq 'HEAD') {
