@@ -25,7 +25,7 @@ sub import_table {
                   file_modification_time($table);
 
     print "Importing product table '$source'\n";
-    open(IN, $source) or die "Can't open '$source' for reading: $!\n";
+    open(IN, "< $source") or die "Can't open '$source' for reading: $!\n";
     my @columns = read_quoted_fields(\*IN);
     die "$source is empty\n" unless @columns;
 
