@@ -835,7 +835,7 @@ sub vendUrl
     $r = $Vend::Cfg->{VendURL}
 		unless defined $r;
 
-	$arguments =~ s!([^\w-_:#=/.%])! '%' . sprintf("%02x", ord($1))!eg
+	$arguments =~ s!([^-\w_:#=/.%])! '%' . sprintf("%02x", ord($1))!eg
 		if defined $arguments && $Vend::Cfg->{NewEscape};
 
 	if(defined $Vend::Cfg->{AlwaysSecure}->{$path}) {
@@ -859,7 +859,7 @@ sub secure_vendUrl
     my($r);
 	return undef unless $Vend::Cfg->{SecureURL};
 
-	$arguments =~ s!([^\w-_:#=/.%])! '%' . sprintf("%02x", $1)!eg
+	$arguments =~ s!([^-\w_:#=/.%])! '%' . sprintf("%02x", $1)!eg
 		if defined $arguments && $Vend::Cfg->{NewEscape};
 
     $r = $Vend::Cfg->{SecureURL};
